==> haskell-gtk-strut-0.1.3.2-341-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-K26rEF3v1afA85QEy6fNaf
key:                  gtk-strut-0.1.3.2-K26rEF3v1afA85QEy6fNaf
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  dd0e476a75cce7952f64a923de93a8fa
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-K26rEF3v1afA85QEy6fNaf
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    gi-gdk-3.0.29-3leWBDJTALFbfD3qiC00E
    gi-gtk-3.0.43-9A6QPuGdBMpAA8CnLgcM1f
    hslogger-1.3.2.0-1NkMetVZZQxCHjmQHJSTJK text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-343-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-DQ3jjEv2Qrm6SK5exwg6ek
key:                  gtk-strut-0.1.3.2-DQ3jjEv2Qrm6SK5exwg6ek
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  9e1bb564bc3fc501bfdf26051d8a4203
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-DQ3jjEv2Qrm6SK5exwg6ek
depends:
    base-4.18.2.1 data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl
    gi-gdk-3.0.29-DBX2WunvKOoBLGQmAvV9j8
    gi-gtk-3.0.43-HpkWtFbKGZzBuACdbNzfMV
    hslogger-1.3.2.0-IyqwOFGVXOR57mWYE4psSE text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
